Authors
*******

- Beraldo Leal <beraldo DOT leal AT cern DOT ch>
- Arthur Baruchi <abaruchi AT ncc DOT unesp DOT br>
- Carlos Eduardo Moreira dos Santos <cadu AT ncc DOT unesp DOT br>
- Diego Rabatone Oliveira <diraol AT ncc DOT unesp DOT br>
- Macártur de Sousa Carvalho <macartur.sc AT gmail DOT com>
- Renan Rodrigo <renanrb AT ime DOT usp DOT br>
- Humberto Diógenes <hdiogenes AT gmail DOT com>
- Antonio Francisco <ajoaoff AT gmail.com>
- Carlos Magno Barbosa <cmagnobarbosa AT gmail DOT com>
- Jose Mauro <zemauror AT gmail DOT com>
- Gleyberson Andrade <gleybersonandrade AT gmail DOT com>


Contributors
============

- Erick Vermot <erick.vermot AT gmail DOT com>
- Luan Gonçalves <luanlg.cco AT gmail DOT com>
- Lucas Felix <lucasgsfelix AT gmail DOT com>
- Raphael Cóbe <rmcobe AT ncc DOT unesp DOT br>
- Rogerio Motitsuki <rogerio.motitsuki AT gmail DOT com>
- Thiago Lopes <thiagolopes AT ncc DOT unesp DOT br>
- Valessio Soares de Brito <contato AT valessiobrito DOT com DOT br>
- Vinicius Arcanjo <viniciusarcanjov AT gmail DOT com>
